# Basic maths

A small demo library for multiplying and dividing numbers.

### Installation
```
pip install basic-maths
```

### Get started
How to multiply one number by another with this lib:

```
from basic_multiplication import Multiplication

# Instantiate a Multiplication object
multiplication = Multiplication(2)

# Call the multiply method
result = multiplication.multiply(5)
```
